# -*- coding: utf-8 -*-

from .cusum import cusum
from .ewma import ewma, mewma
from .mr import mr, xmr
from .xbar_sbar import xbar_sbar, sbar
from .xbar_rbar import xbar_rbar, rbar
from .imrx import imrx
from .imrr import imrr
from .imrmr import imrmr
from .imrstd import imrstd
from .hotelling import Tsquare_single, Tsquare, variation
from .np import np
from .p import p
from .c import c
from .u import u
from .tables import *
